Approximate re-creation of a raster from a quadmesh.
qm_as_raster(x, index = NULL)RasterLayer
The raster is populated with the mean of the values at each corner, which is closest to the interpretation use to create mesh3d from rasters. This can be over ridden by setting 'index' to 1, 2, 3, or 4.
qm_as_raster(quadmesh(etopo))
#> class : RasterLayer
#> dimensions : 135, 540, 72900 (nrow, ncol, ncell)
#> resolution : 0.6666667, 0.6666666 (x, y)
#> extent : -180, 180, -90, 0 (xmin, xmax, ymin, ymax)
#> crs : +proj=longlat +ellps=WGS84 +towgs84=0,0,0,0,0,0,0 +no_defs
#> source : memory
#> names : layer
#> values : -6784.148, 4603.07 (min, max)
#>