Set or return the coordinate system currently in use.
use_crs(crs = NULL)the current value of the in-use coordinate system (may be NULL), if
crs is provided it is returned after being set as the in-use value
If argument crs is NULL, the function returns the current value (which may be NULL).
if (FALSE) { # \dontrun{
use_crs()
use_crs("+proj=laea +datum=WGS84")
use_crs()
} # }